pub struct RemovalShipmentAdjustmentEvent {
    pub posted_date: Option<String>,
    pub adjustment_event_id: Option<String>,
    pub merchant_order_id: Option<String>,
    pub order_id: Option<String>,
    pub transaction_type: Option<String>,
    pub removal_shipment_item_adjustment_list: Option<Vec<RemovalShipmentItemAdjustment>>,
}
RemovalShipmentAdjustmentEvent : A financial adjustment event for FBA liquidated inventory. A positive value indicates money owed to Amazon by the buyer (for example, when the charge was incorrectly calculated as less than it should be). A negative value indicates a full or partial refund owed to the buyer (for example, when the buyer receives damaged items or fewer items than ordered).

Fields

posted_date: Option<String>adjustment_event_id: Option<String>

The unique identifier for the adjustment event.

merchant_order_id: Option<String>

The merchant removal orderId.

order_id: Option<String>

The orderId for shipping inventory.

transaction_type: Option<String>

The type of removal order. Possible values: * WHOLESALE_LIQUIDATION.

removal_shipment_item_adjustment_list: Option<Vec<RemovalShipmentItemAdjustment>>

A comma-delimited list of Removal shipmentItemAdjustment details for FBA inventory.

Implementations

A financial adjustment event for FBA liquidated inventory. A positive value indicates money owed to Amazon by the buyer (for example, when the charge was incorrectly calculated as less than it should be). A negative value indicates a full or partial refund owed to the buyer (for example, when the buyer receives damaged items or fewer items than ordered).